@@ -169,6 +169,17 @@ module Bunny
       @connection = connection
       @logger     = connection.logger
       @id         = id || @connection.next_channel_id
+
+      # channel allocator is exhausted
+      if @id < 0
+        msg = "Cannot open a channel: max number of channels on connection reached. Connection channel_max value: #{@connection.channel_max}"
+        @logger.error(msg)
+
+        raise msg
+      else
+        @logger.debug { "Allocated channel id: #{@id}" }
+      end
+
       @status     = :opening
 
       @connection.register_channel(self)
@@ -254,15 +265,6 @@ module Bunny
       @status == :closed
     end
 
-    def to_s
-      oid = ("0x%x" % (self.object_id << 1))
-      "<#{self.class.name}:#{oid} number=#{@channel.id} @open=#{open?} connection=#{@connection.to_s}>"
-    end
-
-    def inspect
-      to_s
-    end
-
     #
     # @group Backwards compatibility with 0.8.0
     #
@@ -413,6 +415,8 @@ module Bunny
     # @see http://rubybunny.info/articles/extensions.html RabbitMQ Extensions guide
     # @api public
     def queue(name = AMQ::Protocol::EMPTY_STRING, opts = {})
+      throw ArgumentError.new("queue name must not be nil") if name.nil?
+
       q = find_queue(name) || Bunny::Queue.new(self, name, opts)
 
       register_queue(q)
@@ -646,7 +650,7 @@ module Bunny
 
       @connection.send_frame(AMQ::Protocol::Basic::Qos.encode(@id, 0, count, global))
 
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_basic_qos_ok = wait_on_continuations
       end
       raise_if_continuation_resulted_in_a_channel_error!
@@ -667,7 +671,7 @@ module Bunny
       raise_if_no_longer_open!
 
       @connection.send_frame(AMQ::Protocol::Basic::Recover.encode(@id, requeue))
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_basic_recover_ok = wait_on_continuations
       end
       raise_if_continuation_resulted_in_a_channel_error!
@@ -874,7 +878,7 @@ module Bunny
           arguments))
 
       begin
-        Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+        with_continuation_timeout do
           @last_basic_consume_ok = wait_on_continuations
         end
       rescue Exception => e
@@ -924,7 +928,7 @@ module Bunny
           consumer.arguments))
 
       begin
-        Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+        with_continuation_timeout do
           @last_basic_consume_ok = wait_on_continuations
         end
       rescue Exception => e
@@ -959,7 +963,7 @@ module Bunny
     def basic_cancel(consumer_tag)
       @connection.send_frame(AMQ::Protocol::Basic::Cancel.encode(@id, consumer_tag, false))
 
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_basic_cancel_ok = wait_on_continuations
       end
 
@@ -983,7 +987,8 @@ module Bunny
 
     # Declares a queue using queue.declare AMQP 0.9.1 method.
     #
-    # @param [String] name Queue name
+    # @param [String] name The name of the queue or an empty string to let RabbitMQ generate a name.
+    #                      Note that LF and CR characters will be stripped from the value.
     # @param [Hash] opts Queue properties
     #
     # @option opts [Boolean] durable (false)     Should information about this queue be persisted to disk so that it
@@ -1001,16 +1006,28 @@ module Bunny
     def queue_declare(name, opts = {})
       raise_if_no_longer_open!
 
-      @connection.send_frame(AMQ::Protocol::Queue::Declare.encode(@id,
-          name,
+      # strip trailing new line and carriage returns
+      # just like RabbitMQ does
+      safe_name = name.gsub(/[\r\n]/, "")
+      @pending_queue_declare_name = safe_name
+      @connection.send_frame(
+        AMQ::Protocol::Queue::Declare.encode(@id,
+          @pending_queue_declare_name,
           opts.fetch(:passive, false),
           opts.fetch(:durable, false),
           opts.fetch(:exclusive, false),
           opts.fetch(:auto_delete, false),
           false,
           opts[:arguments]))
-      @last_queue_declare_ok = wait_on_continuations
 
+      begin
+        with_continuation_timeout do
+          @last_queue_declare_ok = wait_on_continuations
+        end
+      ensure
+        # clear pending continuation context if it belongs to us
+        @pending_queue_declare_name = nil if @pending_queue_declare_name == safe_name
+      end
       raise_if_continuation_resulted_in_a_channel_error!
 
       @last_queue_declare_ok
@@ -1035,7 +1052,7 @@ module Bunny
           opts[:if_unused],
           opts[:if_empty],
           false))
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_queue_delete_ok = wait_on_continuations
       end
       raise_if_continuation_resulted_in_a_channel_error!
@@ -1055,7 +1072,7 @@ module Bunny
 
       @connection.send_frame(AMQ::Protocol::Queue::Purge.encode(@id, name, false))
 
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_queue_purge_ok = wait_on_continuations
       end
       raise_if_continuation_resulted_in_a_channel_error!
@@ -1091,7 +1108,7 @@ module Bunny
           (opts[:routing_key] || opts[:key]),
           false,
           opts[:arguments]))
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_queue_bind_ok = wait_on_continuations
       end
 
@@ -1126,7 +1143,7 @@ module Bunny
           exchange_name,
           opts[:routing_key],
           opts[:arguments]))
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_queue_unbind_ok = wait_on_continuations
       end
 
@@ -1139,26 +1156,30 @@ module Bunny
 
     # @group Exchange operations (exchange.*)
 
-    # Declares a echange using echange.declare AMQP 0.9.1 method.
+    # Declares a exchange using echange.declare AMQP 0.9.1 method.
     #
-    # @param [String] name Exchange name
+    # @param [String] name The name of the exchange. Note that LF and CR characters
+    #                       will be stripped from the value.
     # @param [String,Symbol] type Exchange type, e.g. :fanout or :topic
     # @param [Hash] opts Exchange properties
     #
-    # @option opts [Boolean] durable (false)     Should information about this echange be persisted to disk so that it
+    # @option opts [Boolean] durable (false)     Should information about this exchange be persisted to disk so that it
     #                                            can survive broker restarts? Typically set to true for long-lived exchanges.
-    # @option opts [Boolean] auto_delete (false) Should this echange be deleted when it is no longer used?
+    # @option opts [Boolean] auto_delete (false) Should this exchange be deleted when it is no longer used?
     # @option opts [Boolean] passive (false)   If true, exchange will be checked for existence. If it does not
     #                                          exist, {Bunny::NotFound} will be raised.
     #
     # @return [AMQ::Protocol::Exchange::DeclareOk] RabbitMQ response
-    # @see http://rubybunny.info/articles/echanges.html Exchanges and Publishing guide
+    # @see http://rubybunny.info/articles/exchanges.html Exchanges and Publishing guide
     # @api public
     def exchange_declare(name, type, opts = {})
       raise_if_no_longer_open!
 
+      # strip trailing new line and carriage returns
+      # just like RabbitMQ does
+      safe_name = name.gsub(/[\r\n]/, "")
       @connection.send_frame(AMQ::Protocol::Exchange::Declare.encode(@id,
-          name,
+          safe_name,
           type.to_s,
           opts.fetch(:passive, false),
           opts.fetch(:durable, false),
@@ -1166,7 +1187,7 @@ module Bunny
           opts.fetch(:internal, false),
           false, # nowait
           opts[:arguments]))
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_exchange_declare_ok = wait_on_continuations
       end
 
@@ -1191,7 +1212,7 @@ module Bunny
           name,
           opts[:if_unused],
           false))
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_exchange_delete_ok = wait_on_continuations
       end
 
@@ -1235,7 +1256,7 @@ module Bunny
           opts[:routing_key],
           false,
           opts[:arguments]))
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_exchange_bind_ok = wait_on_continuations
       end
 
@@ -1279,7 +1300,7 @@ module Bunny
           opts[:routing_key],
           false,
           opts[:arguments]))
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_exchange_unbind_ok = wait_on_continuations
       end
 
@@ -1307,7 +1328,7 @@ module Bunny
       raise_if_no_longer_open!
 
       @connection.send_frame(AMQ::Protocol::Channel::Flow.encode(@id, active))
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_channel_flow_ok = wait_on_continuations
       end
       raise_if_continuation_resulted_in_a_channel_error!
@@ -1328,7 +1349,7 @@ module Bunny
       raise_if_no_longer_open!
 
       @connection.send_frame(AMQ::Protocol::Tx::Select.encode(@id))
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_tx_select_ok = wait_on_continuations
       end
       raise_if_continuation_resulted_in_a_channel_error!
@@ -1344,7 +1365,7 @@ module Bunny
       raise_if_no_longer_open!
 
       @connection.send_frame(AMQ::Protocol::Tx::Commit.encode(@id))
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_tx_commit_ok = wait_on_continuations
       end
       raise_if_continuation_resulted_in_a_channel_error!
@@ -1359,7 +1380,7 @@ module Bunny
       raise_if_no_longer_open!
 
       @connection.send_frame(AMQ::Protocol::Tx::Rollback.encode(@id))
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_tx_rollback_ok = wait_on_continuations
       end
       raise_if_continuation_resulted_in_a_channel_error!
@@ -1406,7 +1427,7 @@ module Bunny
       @confirms_callback = callback
 
       @connection.send_frame(AMQ::Protocol::Confirm::Select.encode(@id, false))
-      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout) do
+      with_continuation_timeout do
         @last_confirm_select_ok = wait_on_continuations
       end
       raise_if_continuation_resulted_in_a_channel_error!
@@ -1578,7 +1599,11 @@ module Bunny
 
     # @return [String] Brief human-readable representation of the channel
     def to_s
-      "#<#{self.class.name}:#{object_id} @id=#{self.number} @connection=#{@connection.to_s}>"
+      "#<#{self.class.name}:#{object_id} @id=#{self.number} @connection=#{@connection.to_s}> @open=#{open?}"
+    end
+
+    def inspect
+      to_s
     end
 
 
@@ -1586,6 +1611,11 @@ module Bunny
     # Implementation
     #
 
+    # @private
+    def with_continuation_timeout(&block)
+      Bunny::Timeout.timeout(wait_on_continuations_timeout, ClientTimeout, &block)
+    end
+
     # @private
     def register_consumer(consumer_tag, consumer)
       @consumer_mutex.synchronize do
@@ -1609,12 +1639,33 @@ module Bunny
       end
     end
 
+    # @private
+    def pending_server_named_queue_declaration?
+      @pending_queue_declare_name && @pending_queue_declare_name.empty?
+    end
+
+    # @private
+    def can_accept_queue_declare_ok?(method)
+      @pending_queue_declare_name == method.queue ||
+        pending_server_named_queue_declaration?
+    end
+
     # @private
     def handle_method(method)
       @logger.debug { "Channel#handle_frame on channel #{@id}: #{method.inspect}" }
       case method
       when AMQ::Protocol::Queue::DeclareOk then
-        @continuations.push(method)
+        # safeguard against late arrivals of responses and
+        # so on, see ruby-amqp/bunny#558
+        if can_accept_queue_declare_ok?(method)
+          @continuations.push(method)
+        else
+          if !pending_server_named_queue_declaration?
+            # this response is for an outdated/overwritten
+            # queue.declare, drop it
+            @logger.warn "Received a queue.declare-ok response for a mismatching queue (#{method.queue} instead of #{@pending_queue_declare_name}) on channel #{@id} possibly due to a timeout, ignoring it"
+          end
+        end
       when AMQ::Protocol::Queue::DeleteOk then
         @continuations.push(method)
       when AMQ::Protocol::Queue::PurgeOk then
