@@ -29,6 +29,7 @@ module Bunny
         @interval = [(period / 2) - 1, 0.4].max
 
         @thread = Thread.new(&method(:run))
+        @thread.report_on_exception = false if @thread.respond_to?(:report_on_exception)
       end
     end
 
@@ -63,7 +64,7 @@ module Bunny
 
       if now > (@last_activity_time + @interval)
         @logger.debug { "Sending a heartbeat, last activity time: #{@last_activity_time}, interval (s): #{@interval}" }
-        @transport.write_without_timeout(AMQ::Protocol::HeartbeatFrame.encode)
+        @transport.write_without_timeout(AMQ::Protocol::HeartbeatFrame.encode, true)
       end
     end
   end
