@@ -1,9 +1,23 @@
 # -*- coding: utf-8 -*-
+
+require "timeout"
+
 module Bunny
   # Unit, integration and stress testing toolkit
   class TestKit
     class << self
 
+      def poll_while(timeout = 60, &probe)
+        Timeout.timeout(timeout) {
+          sleep 0.1 while probe.call
+        }
+      end
+      def poll_until(timeout = 60, &probe)
+        Timeout.timeout(timeout) {
+          sleep 0.1 until probe.call
+        }
+      end
+
       # @return [Integer] Random integer in the range of [a, b]
       # @api private
       def random_in_range(a, b)
