@@ -2,8 +2,8 @@ require "spec_helper"
 
 describe Bunny::Queue, "#pop" do
   let(:connection) do
-    c = Bunny.new(:user => "bunny_gem", :password => "bunny_password", :vhost => "bunny_testbed",
-                  :automatically_recover => false)
+    c = Bunny.new(username: "bunny_gem", password: "bunny_password", vhost: "bunny_testbed",
+                  automatically_recover: false)
     c.start
     c
   end
@@ -16,11 +16,11 @@ describe Bunny::Queue, "#pop" do
     it "fetches a messages which is automatically acknowledged" do
       ch = connection.create_channel
 
-      q  = ch.queue("", :exclusive => true)
+      q  = ch.queue("", exclusive: true)
       x  = ch.default_exchange
 
       msg = "xyzzy"
-      x.publish(msg, :routing_key => q.name)
+      x.publish(msg, routing_key: q.name)
 
       sleep(0.5)
       get_ok, properties, content = q.pop
@@ -41,7 +41,7 @@ describe Bunny::Queue, "#pop" do
     it "returns an empty response" do
       ch = connection.create_channel
 
-      q  = ch.queue("", :exclusive => true)
+      q  = ch.queue("", exclusive: true)
       q.purge
 
       get_empty, properties, content = q.pop
@@ -54,3 +54,27 @@ describe Bunny::Queue, "#pop" do
     end
   end
 end
+
+
+describe Bunny::Channel, "#basic_get" do
+  let(:connection) do
+    c = Bunny.new(username: "bunny_gem", password: "bunny_password", vhost: "bunny_testbed",
+                  automatically_recover: false, continuation_timeout: 3000)
+    c.start
+    c
+  end
+
+  after :each do
+    connection.close if connection.open?
+  end
+
+  context "with a non-existent queue" do
+    it "throws a NOT_FOUND" do
+      ch = connection.create_channel
+
+      expect do
+        ch.basic_get "non_existent_#{rand.to_s}"
+      end.to raise_error(Bunny::NotFound)
+    end
+  end
+end
