@@ -2,7 +2,7 @@ require "spec_helper"
 
 describe "Published message" do
   let(:connection) do
-    c = Bunny.new(:user => "bunny_gem", :password => "bunny_password", :vhost => "bunny_testbed")
+    c = Bunny.new(username: "bunny_gem", password: "bunny_password", vhost: "bunny_testbed")
     c.start
     c
   end
@@ -15,12 +15,12 @@ describe "Published message" do
     it "routes the messages" do
       ch = connection.create_channel
 
-      q  = ch.queue("", :exclusive => true)
+      q  = ch.queue("", exclusive: true)
       x  = ch.fanout("amq.fanout")
       q.bind(x)
 
       rk = "a" * 254
-      x.publish("xyzzy", :routing_key => rk, :persistent => true)
+      x.publish("xyzzy", routing_key: rk, persistent: true)
 
       sleep(1)
       expect(q.message_count).to eq 1
@@ -37,12 +37,12 @@ describe "Published message" do
     it "routes the messages" do
       ch = connection.create_channel
 
-      q  = ch.queue("", :exclusive => true)
+      q  = ch.queue("", exclusive: true)
       x  = ch.fanout("amq.fanout")
       q.bind(x)
 
       rk = "a" * 255
-      x.publish("xyzzy", :routing_key => rk, :persistent => true)
+      x.publish("xyzzy", routing_key: rk, persistent: true)
 
       sleep(1)
       expect(q.message_count).to eq 1
@@ -59,13 +59,13 @@ describe "Published message" do
     it "fails with a connection exception" do
       ch = connection.create_channel
 
-      q  = ch.queue("", :exclusive => true)
+      q  = ch.queue("", exclusive: true)
       x  = ch.fanout("amq.fanout")
       q.bind(x)
 
       rk = "a" * 256
       expect do
-        x.publish("xyzzy", :routing_key => rk, :persistent => true)
+        x.publish("xyzzy", routing_key: rk, persistent: true)
       end.to raise_error(ArgumentError)
 
       ch.close
