@@ -1,6 +1,8 @@
 require "spec_helper"
 require "rabbitmq/http/client"
 
+require "bunny/concurrent/condition"
+
 describe "Connection recovery" do
   let(:http_client) { RabbitMQ::HTTP::Client.new("http://127.0.0.1:15672") }
   let(:logger) { Logger.new($stderr).tap {|logger| logger.level = ENV["BUNNY_LOG_LEVEL"] || Logger::WARN } }
@@ -40,6 +42,21 @@ describe "Connection recovery" do
     end
   end
 
+  it "provides a recovery completion callback" do
+    with_open do |c|
+      latch = Bunny::Concurrent::Condition.new
+      c.after_recovery_completed do
+        latch.notify
+      end
+
+      ch = c.create_channel
+      sleep 1.0
+      close_all_connections!
+      poll_until { c.open? && ch.open? }
+      poll_until { latch.none_threads_waiting? }
+    end
+  end
+
   it "recovers channels (with multiple hosts)" do
     with_open_multi_host do |c|
       ch1 = c.create_channel
@@ -221,7 +238,7 @@ describe "Connection recovery" do
 
       close_all_connections!
 
-      wait_for_recovery_with { exchange_names_in_vhost("/").include?(source.name) }
+      wait_for_recovery_with { connections.any? && exchange_names_in_vhost("/").include?(source.name) }
       ch.confirm_select
 
       source.publish("msg", routing_key: "")
@@ -270,7 +287,6 @@ describe "Connection recovery" do
       destination = ch.fanout("destination.exchange.recovery.example", auto_delete: true)
 
       source2      = ch2.fanout("source.exchange.recovery.example", no_declare: true)
-      destination2 = ch2.fanout("destination.exchange.recovery.example", no_declare: true)
 
       destination.bind(source)
 
@@ -284,7 +300,7 @@ describe "Connection recovery" do
 
       close_all_connections!
 
-      wait_for_recovery_with { exchange_names_in_vhost("/").include?(source.name) }
+      wait_for_recovery_with { connections.any? && exchange_names_in_vhost("/").include?(source.name) }
 
       ch2.confirm_select
 
@@ -413,15 +429,11 @@ describe "Connection recovery" do
   end
 
   def poll_while(&probe)
-    Timeout.timeout(20) {
-      sleep 0.1 while probe.call
-    }
+    Bunny::TestKit.poll_while(&probe)
   end
 
   def poll_until(&probe)
-    Timeout.timeout(20) {
-      sleep 0.1 until probe.call
-    }
+    Bunny::TestKit.poll_until(&probe)
   end
 
   def with_open(c = Bunny.new(network_recovery_interval: recovery_interval,
@@ -430,7 +442,7 @@ describe "Connection recovery" do
     c.start
     block.call(c)
   ensure
-    c.close
+    c.close(false) rescue nil
   end
 
   def with_open_multi_host(&block)
