@@ -4,7 +4,8 @@ require "spec_helper"
 unless ENV["CI"]
   describe "Concurrent publishers sharing a connection" do
     before :all do
-      @connection = Bunny.new(:user => "bunny_gem", :password => "bunny_password", :vhost => "bunny_testbed", :automatically_recover => false)
+      @connection = Bunny.new(username: "bunny_gem", password: "bunny_password",
+        vhost: "bunny_testbed", automatically_recover: false)
       @connection.start
     end
 
@@ -13,7 +14,7 @@ unless ENV["CI"]
     end
 
     let(:concurrency) { 24 }
-    let(:rate)        { 5_000 }
+    let(:messages)    { 5_000 }
 
     it "successfully finish publishing" do
       body = "сообщение"
@@ -32,10 +33,10 @@ unless ENV["CI"]
           cht = chs[i]
           x   = cht.default_exchange
 
-          rate.times do
+          messages.times do
             x.publish(body)
           end
-          puts "Published #{rate} messages..."
+          puts "Published #{messages} messages..."
           cht.wait_for_confirms
         end
         t.abort_on_exception = true
